@@ -1,4 +1,6 @@
 from splight_models import (
+    Alert,
+    AlertCondition,
     Asset,
     Attribute,
     File,
@@ -9,11 +11,11 @@ from splight_models import (
     Query,
     Node,
     BlockchainContract,
-    Component,
     HubComponent,
     ComponentObject,
     ComponentCommand,
     Secret,
+    SetPoint,
 )
 
 
@@ -21,11 +23,17 @@ CLASSMAP = {
     Component: {
         "path": "v2/engine/component/components"
     },
+    Alert: {
+        "path": "v2/engine/alert/alerts"
+    },
+    AlertCondition: {
+        "path": "v2/engine/alert/conditions"
+    },
     Asset: {
         "path": "v2/engine/assets"
     },
     Attribute: {
-        "path": "v2/engine/assets"
+        "path": "v2/engine/attributes"
     },
     Edge: {
         "path": "v2/engine/graph/edges"
@@ -60,4 +68,7 @@ CLASSMAP = {
     HubComponent: {
         "path": "v2/engine/hub/component-versions"
     },
+    SetPoint: {
+        "path": "v2/engine/setpoints"
+    },
 }
