@@ -65,6 +65,7 @@ class DatabaseClient(AbstractDatabaseClient, AbstractRemoteClient):
             output = self._update(path, instance.id, instance)
         else:
             output = self._create(path, instance)
+            instance.id = output["id"]
         return constructor.parse_obj(output)
 
     @retry(REQUEST_EXCEPTIONS, tries=3, delay=1)
@@ -95,6 +96,7 @@ class DatabaseClient(AbstractDatabaseClient, AbstractRemoteClient):
         first: bool = False,
         limit_: int = -1,
         skip_: int = 0,
+        page_size: int = -1,
         deleted: bool = False,
         **kwargs,
     ) -> List[BaseModel]:
@@ -105,6 +107,7 @@ class DatabaseClient(AbstractDatabaseClient, AbstractRemoteClient):
             limit_=limit_,
             skip_=skip_,
             deleted=deleted,
+            page_size=page_size,
             **kwargs,
         )
         parsed = [
