@@ -1,4 +1,5 @@
 from splight_models.asset import *
+from splight_models.alert import Alert, AlertCondition
 from splight_models.attribute import *
 from splight_models.blockchain import *
 from splight_models.communication import *
@@ -17,3 +18,4 @@ from splight_models.user import *
 from splight_models.variable import *
 from splight_models.webhook import *
 from splight_models.secret import *
+from splight_models.setpoint import *
