@@ -1,4 +1,10 @@
-from splight_models.constants import ComponentSize, RestartPolicy, LogginLevel, ComponentStatus
+from splight_models.constants import (
+    ComponentSize,
+    RestartPolicy,
+    LogginLevel,
+    ComponentStatus,
+    ComponentType
+)
 from splight_models.asset import Asset
 from splight_models.attribute import Attribute
 from splight_models.base import SplightBaseModel
@@ -79,10 +85,6 @@ class ComponentObject(SplightBaseModel):
     type: str
     data: List[InputParameter]
 
-    @staticmethod
-    def get_event_name(type: str, action: EventActions) -> str:
-        return f"{type.lower()}_{action}"
-
 
 class ComponentCommandResponse(SplightBaseModel):
     return_value: Optional[str] = None
@@ -126,6 +128,7 @@ class BaseComponent(SplightBaseModel):
     name: Optional[str] = None
     version: str
     custom_types: Optional[List[CustomType]] = []
+    component_type: Optional[ComponentType]
     input: Optional[List[InputParameter]] = []
     output: Optional[List[Output]] = []
     commands: Optional[List[Command]] = []
