@@ -1,9 +1,14 @@
-# TODO remove this file
 import logging
 from enum import Enum, IntEnum
 
 
-class SeverityType(str, Enum):
+class ChoiceMixin(str, Enum):
+    @classmethod
+    def choices(cls):
+        return [(key.value.lower(), key.name.capitalize()) for key in cls]
+
+
+class SeverityType(ChoiceMixin):
     system = 'system'
     info = 'info'
     low = 'low'
@@ -12,6 +17,26 @@ class SeverityType(str, Enum):
     critical = 'critical'
 
 
+class AlertStatus(ChoiceMixin):
+    ALERT = "alert"
+    NO_ALERT = "no_alert"
+    NO_DATA = "no_data"
+
+
+class AlertOperator(ChoiceMixin):
+    GREATER_THAN = "gt"
+    GREATER_THAN_OR_EQUAL = "ge"
+    LOWER_THAN = "lt"
+    LOWER_THAN_OR_EQUAL = "le"
+    EQUAL = "eq"
+
+
+class AlertVariableType(ChoiceMixin):
+    STR = "str"
+    INT = "int"
+    FLOAT = "float"
+
+
 class ComponentSize(str, Enum):
     small = "small"
     medium = "medium"
@@ -53,7 +78,14 @@ class DeploymentStatus(str, Enum):
     UNKNOWN = "Unknown"
 
 
-class ComponentStatus(str, Enum):
+class MinComponentCapacity(ChoiceMixin):
+    SMALL = 'small'
+    MEDIUM = 'medium'
+    LARGE = 'large'
+    VERY_LARGE = 'very_large'
+
+
+class ComponentStatus(ChoiceMixin):
     STOPPED = "Stopped"
     PENDING = "Pending"
     RUNNING = "Running"
@@ -62,20 +94,27 @@ class ComponentStatus(str, Enum):
     UNKNOWN = "Unknown"
 
 
-class PrivacyPolicy(str, Enum):
+class PrivacyPolicy(ChoiceMixin):
     PUBLIC = "public"
     PRIVATE = "private"
 
 
-class VerificationLevel(str, Enum):
+class VerificationLevel(ChoiceMixin):
     VERIFIED = "verified"
     UNVERIFIED = "unverified"
     OFFICIAL = "official"
 
 
-class BuildStatus(str, Enum):
+class BuildStatus(ChoiceMixin):
     PENDING = "pending"
     BUILDING = "building"
     FAILED = "failed"
     SUCCESS = "success"
     UNKNOWN = "unknown"
+
+
+class ComponentType(ChoiceMixin):
+    ALGORITHM = "algorithm"
+    NETWORK = "network"
+    CONNECTOR = "connector"
+    SIMULATOR = "simulator"
